@@ -60,25 +60,27 @@
             })
 
   library(utils)
-  packageStartupMessage(gvisWelcomeMessage())    
-  
+  packageStartupMessage(gvisWelcomeMessage())
   invisible()
 }
 
 gvisWelcomeMessage <- function(){
   
-       paste("\nWelcome to googleVis version ", packageDescription("googleVis")$Version, "\n\n",
-      "Type ?googleVis to access the overall documentation and\n",
-      "vignette('googleVis') for the package vignette.\n",
-      "You can execute the demo of the package via: demo(googleVis)\n\n",  
-      "More information is available on the googleVis project web-site:\n",
-                        "http://code.google.com/p/google-motion-charts-with-r/\n\n",
-      
-      "Please read also the Google Visualisation API Terms of Use:\n",
-      "http://code.google.com/apis/visualization/terms.html\n\n",
-      
-      "Feel free to send us an email <rvisualisation@gmail.com>\n",
-      "if you would like to be keept informed of new versions,\n",
-      "or if you have any feedback, ideas, suggestions or would\n",
-      "like to collaborate.\n\n", sep="")
+  paste("To suppress the following message use the statement:\n",
+        "suppressPackageStartupMessages(library(googleVis))\n\n",       
+        "Welcome to googleVis version ", packageDescription("googleVis")$Version, "\n\n",
+        "Type ?googleVis to access the overall documentation and\n",
+        "vignette('googleVis') for the package vignette.\n",
+        "You can execute the demo of the package via: demo(googleVis)\n\n",  
+        "More information is available on the googleVis project web-site:\n",
+        "http://code.google.com/p/google-motion-charts-with-r/\n\n",
+        
+        "Please read also the Google Visualisation API Terms of Use:\n",
+        "http://code.google.com/apis/visualization/terms.html\n\n",
+        
+        "Feel free to send us an email <rvisualisation@gmail.com>\n",
+        "if you would like to be keept informed of new versions,\n",
+        "or if you have any feedback, ideas, suggestions or would\n",
+        "like to collaborate.\n",
+          sep="")
 }
